@@ -15,8 +15,6 @@ from raytraverse import io
 from raytraverse.utility import imagetools as itl
 from raytraverse.utility import pool_call
 from raytraverse.mapper import ViewMapper
-from raytraverse.evaluate import PositionIndex
-from raytraverse.evaluate.retina import rgcf_density
 
 
 def gss_compute(imgs, illums=None, save=False, suffix="_rg.hdr", outdir=None,
@@ -94,6 +92,91 @@ def l_b(b, c, phi):
 
 
 class GSS:
+    """calculate GSS for images with angular fisheye projection
+
+    application of model described in:
+
+        A GENERIC GLARE SENSATION MODEL BASED ON THE HUMAN VISUAL SYSTEM
+        Vissenberg, M.C.J.M., Perz, M., Donners, M.A.H., Sekulovski, D.
+        Signify Research, Eindhoven, THE NETHERLANDS
+        gilles.vissenberg@signify.com
+        DOI 10.25039/x48.2021.0P23
+
+    see methods for citations associated with each step in model.
+
+    the model requires the following steps:
+
+    Done when setting an image with a new resolution:
+    1. calculate solid angle of pixels
+    2. calculate eccentricity from guth position idx
+
+    Steps for applying model to an image:
+    1. calculate eye illuminance from image
+    2. mask non-glare source pixels (not described in model, fixed thresh)
+    3. calculate pupil area and diameter
+    4. calculate global retinal irradiance
+    5. calculate incident retinal irradiance of glare sources
+    6. apply PSF to (5)
+    7. apply movement affecting adaptation to (6)
+    8. apply movement affecting direct response to (6)
+    9. calculate local adaptation using (7)
+    10. calculate V/V_m photoreceptor response (8)
+    11. calculate receptor field response to (10) as DoG
+    12. normalize field response with logistic
+    13. apply position weighting
+    14. sum GSS
+
+    Parameters
+    ----------
+    view:
+        can be None, a view file, a ViewMapperr, or an hdrimage with
+        a valid view specification (must be -vta)
+    gst:
+        glare source threshold (cd/m^2)
+    age:
+        age of observer
+    f:
+        eye focal length
+    scale:
+        factor to apply to raw pixel values to convert to cd/m^2
+    pigmentation:
+        from Ijspeert et al. 1993:
+            mean for blue eyes: 0.16
+            brown eyes: 0.106
+            dark brown eyes: 0.056
+    fwidth: Union[int, float], optional
+        the width of the frame for psf
+    psf: bool, optional
+        apply pointspread function for light arriving at retina
+    adaptmove: bool, optional
+        apply involuntary eye movement effect on local adaptation
+    directmove: book, optional
+        apply involuntary eye movement effect on direct cone response
+
+    Notes
+    -----
+    set self.lum, either by initializing with an image, or with the
+    parameter setter, then compute::
+
+        gss = GSS("img.hdr")
+        gss.lum = "img.hdr"
+        score = gss.compute()
+
+    additional images can be loaded and computed with the parameter setter
+    by calling images with the same resolution and view size on an
+    initialized object, subsantial re-computation can be avoided.
+
+    Alternatively, to get access to process arrays or to override pupil
+    adaptation and or isolating glare sources::
+
+        e_g, pupa, pupd = self.adapt(ev_eye)
+        img_gs = self.get_glare_sources()
+        r_g, parrays = self.glare_response(img_gs, e_g, pupa, pupd,
+        return_arrays=True)
+
+    For processing multiple images with the same GSS initialization in
+    parallel, see hvsgsm.gss_compute()
+    """
 
     # eccentricity min and max scaling for field width in response
     # from Vissenberg et al. (.12, 0.009)
@@ -102,8 +185,8 @@ class GSS:
 
     # coefficients for logistic response function
     # from Vissenberg et al. (22, 0.25)
-    fr_a = 44
-    fr_b = 0.2
+    fr_a = 22
+    fr_b = 0.25
 
     # coeficient for DoG in linear response
     # from Vissenberg et al.  0.67
@@ -119,116 +202,16 @@ class GSS:
     contrast = 0.8
 
     def __init__(self, view=None, gst=0, age=40, f=16.67, scale=179,
-                 pigmentation=0.106, fwidth=10, eccmethod="density",
-                 calibration=1.0, shade=True, psf=True, adaptmove=True,
-                 directmove=True):
-        """calculate GSS for images with angular fisheye projection
-
-        application of model described in:
-         A GENERIC GLARE SENSATION MODEL BASED ON THE HUMAN VISUAL SYSTEM
-        Vissenberg, M.C.J.M., Perz, M., Donners, M.A.H., Sekulovski, D.
-        Signify Research, Eindhoven, THE NETHERLANDS
-        gilles.vissenberg@signify.com
-        DOI 10.25039/x48.2021.0P23
-
-        see methods for citations associated with each step in model.
-
-        the model requires the following steps:
-
-        Done when setting an image with a new resolution:
-        1. calculate solid angle of pixels
-        2. calculate eccentricity from guth position iidx
-
-        Steps for applying model to an image:
-        1. calculate eye illuminance from image
-        2. mask non-glare source pixels (not described in model, fixed thresh)
-        3. calculate pupil area and diameter
-        4. calculate global retinal irradiance
-        5. calculate incident retinal irradiance of glare sources
-        6. apply PSF to (5)
-        7. apply movement affecting adaptation to (6)
-        8. apply movement affecting direcct response to (6)
-        9. calculate local adaptation using (7)
-        10. calculate V/V_m photoreceptor response (8)
-        11. calculate receptor field response to (10) as DoG
-        12. normalize field response with logistic
-        13. apply position weighting* - using guth/iwata, not calibrated values
-            as discribed in Vissenberg et al.
-        14. sum GSS and apply manually set calibration factor (Vissenberg et
-            al. factor not published)
-
-        Parameters
-        ----------
-        view:
-            can be None, a view file, a ViewMapperr, or an hdrimage with
-            a valid view specification (must be -vta)
-        gst:
-            glare source threshold (cd/m^2)
-        age:
-            age of observer
-        f:
-            eye focal length
-        scale:
-            factor to apply to raw pixel values to convert to cd/m^2
-        pigmentation:
-            from Ijspeert et al. 1993:
-                mean for blue eyes: 0.16
-                brown eyes: 0.106
-                dark brown eyes: 0.056
-        fwidth: Union[int, float], optional
-            the width of the frame for psf
-        eccmethod: str
-            method for determining positional importance (maps to emin,emax)
-            "density": use retinal ganglion cell field density (Watson, 2014)
-            "guth": use Guth + Iwata (below horizon) position index
-            "ellipse": use elliptical eccentricity acoording to Vissenberg
-            bad value silently ignored and defaults to density
-        calibration: float, optional
-            default is the average of 3 sources sizes where UGR~19 in the
-            model described in the paper of Vissenberg et al.
-        shade: bool, optional
-            shade incident light according to guth position (.2 @ 16)
-        psf: bool, optional
-            apply pointspread function for light arriving at retina
-        adaptmove: bool, optional
-            apply involuntary eye movement effect on local adaptation
-        directmove: book, optional
-            apply involuntary eye movement effect on direct cone response
-
-        Notes
-        -----
-        set self.lum, either by initializing with an image, or with the
-        parameter setter, then compute::
-
-            gss = GSS("img.hdr")
-            gss.lum = "img.hdr"
-            score = gss.compute()
-
-        additional images can be loaded and computed with the parameter setter
-        by calling images with the same resolution and view size on an
-        initialized object, subsantial re-computation can be avoided.
-
-        Alternatively, to get access to process arrays or to override pupil
-        adaptation and or isolating glare sources::
-
-            e_g, pupa, pupd = self.adapt(ev_eye)
-            img_gs = self.get_glare_sources()
-            r_g, parrays = self.glare_response(img_gs, e_g, pupa, pupd,
-            return_arrays=True)
-
-        For processing multiple images with the same GSS initialization in
-        parallel, see hvsgsm.gss_compute()
-        """
+                 pigmentation=0.106, fwidth=10, psf=True, adaptmove=True,
+                 directmove=True, raw=False):
         self.gst = gst
         self.age = age
         self.f = f
         self.scale = scale
         self.pigmentation = pigmentation
         self.fwidth = fwidth
-        self.calibration = calibration
-        self.shade = shade and eccmethod not in ("ellipse", "guth")
-        self.eccmethod = eccmethod
         self._blur = (psf, adaptmove, directmove)
+        self._raw = raw
         # initialize properties set when an image is loaded
         self._res = 0
         self._vecs = None
@@ -236,7 +219,6 @@ class GSS:
         self._mask = None
         self._nmask = None
         self._lum = None
-        self._eyemask = None
         self._sigma_c = None
         self._pparcmin = None
         if view is None:
@@ -258,15 +240,9 @@ class GSS:
         if self.lum is None:
             raise ValueError("cannot adapt until an image has been set")
         if ev_eye is None:
-            if self.shade:
-                ev_eye = np.einsum('i,i,i,i->', self.ctheta.flat[self.mask],
-                                   self.lum.flat[self.mask],
-                                   self.eyemask.flat[self.mask],
-                                   self.omega.flat[self.mask])
-            else:
-                ev_eye = np.einsum('i,i,i->', self.ctheta.flat[self.mask],
-                                   self.lum.flat[self.mask],
-                                   self.omega.flat[self.mask])
+            ev_eye = np.einsum('i,i,i->', self.ctheta.flat[self.mask],
+                               self.lum.flat[self.mask],
+                               self.omega.flat[self.mask])
         pupa, pupd = self.pupil(ev_eye)
         e_g = self.retinal_irradiance(ev_eye/np.pi, pupa)
         return e_g, pupa, pupd
@@ -278,8 +254,6 @@ class GSS:
                              "set")
         img_gs = np.copy(self.lum, 'C')
         img_gs[self.lum < self.gst] = 0
-        if self.shade:
-            img_gs *= self.eyemask
         return img_gs
 
     def glare_response(self, img_gs, e_g, pupa, pupd, return_arrays=False):
@@ -310,30 +284,40 @@ class GSS:
         """
         if self.lum is None:
             raise ValueError("cannot glare_response until an image has been set")
+        parrays = dict()
         e_r = self.retinal_irradiance(img_gs, pupa)
+        parrays["01_retinal_irrad"] = e_r
         if self._blur[0]:
             e_r_psf = self.apply_psf(e_r, pupd)
+            parrays["02_psf"] = e_r_psf
         else:
             e_r_psf = e_r
         if self._blur[1]:
             e_rg = self.apply_eye_movement_1(e_r_psf)
+            parrays["03_adapt_eye_movement"] = e_rg
         else:
             e_rg = e_r_psf
         if self._blur[2]:
             e_rc = self.apply_eye_movement_2(e_r_psf, e_g)
+            parrays["04_direct_eye_movement"] = e_rc
         else:
             e_rc = e_r_psf
         e_a = self.local_eye_adaptation(e_rg, e_g)
+        parrays["05_local_adaptation"] = e_a
         vvm = self.cone_response(e_rc, e_a)
+        parrays["06_response_ratio"] = vvm
         # r_lin
         r_rf = self.field_response(vvm)
+        parrays["07_response_lin"] = r_rf
         r_g = self.normalized_field_response(r_rf)
-        r_w = self.weight_response(r_g)
+        bfill = np.zeros(r_g.shape[1:])
+        parrays["08_response_log"] = np.stack((*r_g, bfill))
+        if self._raw:
+            r_w = r_g
+        else:
+            r_w = self.weight_response(r_g)
+            parrays["09_weighted_response"] = np.stack((*r_g, bfill))
         if return_arrays:
-            parrays = dict(retinal_irrad=e_r, psf=e_r_psf, response_lin=r_rf,
-                           response_log=r_g,
-                           adapt_eye_movement=e_rg, direct_eye_movement=e_rc,
-                           local_adaptation=e_a, response_ratio=vvm)
             return r_w, parrays
         else:
             return r_w
@@ -358,7 +342,8 @@ class GSS:
         img_gs = self.get_glare_sources()
         r_g = self.glare_response(img_gs, e_g, pupa, pupd)
         if save is not None:
-            io.array2hdr(r_g, save)
+            r_gc = np.stack((*r_g, np.zeros(r_g.shape[1:])))
+            io.carray2hdr(r_gc, save)
         return self.gss(r_g)
 
     @property
@@ -379,7 +364,6 @@ class GSS:
             self._ctheta = ct.reshape(self._lum.shape)
             self._res = r
             self._pparcmin = self.res/(60*self.vm.viewangle)
-            self.eyemask = self._vecs.reshape(-1, 3)
             self.sigma_c = r
 
     @property
@@ -407,25 +391,6 @@ class GSS:
         """cos between vectors and view direction, set via lum"""
         return self._ctheta
 
-    @property
-    def eyemask(self):
-        """face self shading of incident light
-        """
-        return self._eyemask
-
-    @eyemask.setter
-    def eyemask(self, v):
-        """account for eyelid/brow shading applied to incident rays"""
-        p = PositionIndex().positions(self.vm, v)
-        a = 4
-        # center of fade (max posidx = 16)
-        b = 15
-        # minimum shaded contribution
-        c = .2
-        # logistic to ease from 1 (full exposure) to c (shaded)
-        p = (1 - p/(1 + np.exp(-a*(p - b)))*(1 - c)/16)
-        self._eyemask = p.reshape(self.res, self.res)
-
     @property
     def sigma_c(self):
         """position index scaled to eccentricity .009-.12
@@ -442,20 +407,12 @@ class GSS:
 
     @sigma_c.setter
     def sigma_c(self, r):
-        if self.eccmethod == "guth":
-            p = PositionIndex().positions(self.vm, self._vecs.reshape(-1, 3))
-        elif self.eccmethod == "ellipse":
-            # # model described by vissenberg
-            xy = self.vm.xyz2vxy(self._vecs.reshape(-1, 3))*2 - 1
-            p = np.sqrt(np.square(xy[:, 0]/1.05556) +
-                        np.square(xy[:, 1]/0.61111))
-        else:
-            # # retinal ganglion cell field density (combined with partial guth
-            # # masking (applied at adapt step):
-            xy = self.vm.xyz2vxy(self._vecs.reshape(-1, 3))*2 - 1
-            p = 1/rgcf_density(xy)
-        pex = np.percentile(p, (0, 100))
-        s_c = (p - pex[0])*(self.emax - self.emin)/(pex[1] - pex[0]) + self.emin
+        # # model described by vissenberg with greater acceptance below horizon
+        xy = self.vm.xyz2vxy(self._vecs.reshape(-1, 3))*2 - 1
+        vecc = np.where(xy[:, 1] >= 0, xy[:, 1]/0.61111, xy[:, 1]/0.94444)
+        p = np.minimum(np.sqrt(np.square(xy[:, 0]/1.05556) +
+                       np.square(vecc)), 1)
+        s_c = p*(self.emax - self.emin) + self.emin
         self._sigma_c = s_c.reshape(r, r)
 
     @property
@@ -475,6 +432,7 @@ class GSS:
                 vm = ViewMapper(viewangle=180)
         self._vm = vm
 
+    # Step 3
     def pupil(self, ev):
         """calculate pupil area
 
@@ -492,6 +450,7 @@ class GSS:
               0.043*(self.age - 10)*np.exp(-ev/174))
         return np.pi*(pd/2)**2, pd
 
+    # Step 4
     def retinal_irradiance(self, lum, pupa):
         """adjust incident light on retina based on pupil size and focal-length
 
@@ -546,6 +505,7 @@ class GSS:
               1 / (10 + 60 * self.pigmentation - 5 / agefactor), 1]
         return bs, cs
 
+    # Step 6
     def apply_psf(self, e_r, pupd):
         """apply human foveal point spread function
 
@@ -585,6 +545,7 @@ class GSS:
         e_r_psf += base
         return e_r_psf
 
+    # Step 7
     def apply_eye_movement_1(self, e_r):
         """eye movement gaussian adaptation model to blur image at the time-
         scale of adaptation response.
@@ -623,6 +584,7 @@ class GSS:
         # e_rg.flat[self._nmask] = 0
         return e_rg
 
+    # Step 8
     def apply_eye_movement_2(self, e_r, e_g):
         """blur image due to eye movement during direct response
 
@@ -656,6 +618,7 @@ class GSS:
         # e_ra.flat[self._nmask] = 0
         return e_ra
 
+    # Step 9
     def local_eye_adaptation(self, e_r, e_g):
         """calculate locallized eye adaptation
 
@@ -683,6 +646,7 @@ class GSS:
         # e_a.flat[self._nmask] = 0
         return e_a
 
+    # Step 10
     @staticmethod
     def cone_response(e_r, e_a):
         """calculate local response as a fraction of maximum at current
@@ -715,12 +679,15 @@ class GSS:
         vvm = ern/(ern + sigma**n)
         return vvm
 
+    # Step 11
     def field_response(self, vvm):
         """receptive field response
 
-        from Vissenberg et al. 2021 equation (7):
-        R_RF(r) = e^(-r^2/(2σ_c^2)) / (2πσ_c^2) -
-                        K * e^(-r^2/(2σ_s^2)) / (2πσ_s^2)
+        from Vissenberg et al. 2021 equation (7)::
+
+            R_RF(r) = e^(-r^2/(2σ_c^2)) / (2πσ_c^2)
+                      - K * e^(-r^2/(2σ_s^2)) / (2πσ_s^2)
+
         R_RF: receptive field response
         r: distance to receptive field center (degrees)
         σ_c: gaussian width of center (0.009 (center) - 0.12 (edge FOV) degrees)
@@ -739,8 +706,10 @@ class GSS:
         """
         rf_c = np.zeros(vvm.shape)
         rf_s = np.zeros(vvm.shape)
-        # use a log spacing to better capture greater change in ecc near fovea
-        steps = np.exp(np.linspace(np.log(self.emin), np.log(self.emax), 11))
+        # relative change in eccentricity is more important, so log is more
+        # efficient
+        steps = np.exp(np.linspace(np.log(self.emin), np.log(self.emax), 31))
+        # steps = np.linspace(self.emin, self.emax, 16)
         ubounds = np.concatenate(((steps[1:] + steps[:-1])/2, [1]))
         lbounds = np.concatenate(([0], ubounds[:-1]))
         for s, lb, ub in zip(steps, lbounds, ubounds):
@@ -752,6 +721,7 @@ class GSS:
             rf_s[include] = r_s[include]
         return rf_c - self.fr_k*rf_s
 
+    # Step 12
     def normalized_field_response(self, r):
         """normalized non-linear ganglion response
 
@@ -771,10 +741,14 @@ class GSS:
         response_log
             logistic
         """
-        r_g = 1/(1 + np.exp(-self.fr_a*(r - self.fr_b)))
-        r_g.flat[self._nmask] = 0
-        return r_g
+        r_gc = 1/(1 + np.exp(-self.fr_a*(r - self.fr_b)))
+        # track as a seperate receptive field
+        r_go = 1/(1 + np.exp(self.fr_a*(r + self.fr_b)))
+        r_gc.flat[self._nmask] = 0
+        r_go.flat[self._nmask] = 0
+        return np.stack((r_gc, r_go))
 
+    # Step 13
     def weight_response(self, r):
         """weight rectified response by position index
 
@@ -786,9 +760,30 @@ class GSS:
         Returns
         -------
         position weighted glare response
-        """
-        return r / self.sigma_c
 
+        Notes
+        -----
+        fit on guth data using BCD = 2843.58 * e^(x + 1.5 * x^2) / 179
+        with a 2.12 degree source and 34.26 cd/m^2 background
+
+        numpy.polynomial.Polynomial.fit(x, y, 6)
+        where x = eccentricity (.009 -.12 from 0 to 55 degree vertical angle
+        and y = 1/unweighted GSS
+
+        results::
+
+            1.0598742512189994 - 0.9135529200712416·x¹ + 0.8471705621553406·x² -
+            0.5535443101789258·x³ - 0.38772352579868125·x⁴ + 0.9083844574646001·x⁵ -
+            0.07637393810523314·x⁶ - 0.3026419768162507·x⁷
+        """
+        p = np.polynomial.Polynomial([1.0598742512189994, -0.9135529200712416,
+                                      0.8471705621553406, -0.5535443101789258,
+                                      -0.38772352579868125, 0.9083844574646001,
+                                      -0.07637393810523314, -0.3026419768162507],
+                                     domain=[0.009, 0.12])
+        return r * p(self.sigma_c)
+
+    # Step 14
     def gss(self, r_g):
         """calculate minkowski sum on normalized response
 
@@ -798,8 +793,7 @@ class GSS:
         m: minkowski norm (4)
         delta (𝛿): solid angle of pixel (steradians)
         """
-        return self.calibration*np.sum(np.power(r_g, self.norm) *
-                                       self.omega)**(1/self.norm)
+        return np.sum(np.power(r_g, self.norm))**(1/self.norm)
 
 
 
