@@ -5,6 +5,11 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 # =======================================================================
+import os
+import re
+
+from clasp import script_tools as cst
+
 from raytraverse.renderer.radiancerenderer import RadianceRenderer
 from craytraverse.crenderer import cRcontrib
 from raytraverse.formatter import RadianceFormatter as Fmt
@@ -53,12 +58,12 @@ class Rcontrib(RadianceRenderer):
     name = 'rcontrib'
     instance = rcontrib_instance
     ground = True
-    skyres = 18
-    srcn = 325
+    skyres = 15
+    srcn = 226
     modname = "skyglow"
 
     def __init__(self, rayargs=None, scene=None, nproc=None,
-                 skyres=18, modname='skyglow', ground=True,
+                 skyres=15, modname='skyglow', ground=True,
                  default_args=True):
         scene = self.setup(scene, ground, modname, skyres)
         super().__init__(rayargs, scene, nproc=nproc,
@@ -95,7 +100,11 @@ class Rcontrib(RadianceRenderer):
         cls.ground = ground
         if scene is not None:
             srcdef = Fmt.get_skydef((1, 1, 1), ground=ground, name=modname)
-            scene = Fmt.add_source(scene, srcdef)
+            ocom = f'oconv -f -i {scene} -'
+            scene = scene.rsplit(".", 1)[0] + "_sky.oct"
+            if not os.path.isfile(scene):
+                f = open(scene, 'wb')
+                cst.pipeline([ocom], outfile=f, inp=srcdef, close=True)
         cls.skyres = skyres
         cls.srcn = cls.skyres**2 + ground
         cls.modname = modname
@@ -122,4 +131,16 @@ class Rcontrib(RadianceRenderer):
         """
         args = (f" -V+ {args} -w- -e 'side:{cls.skyres}' -f scbins.cal "
                 f"-b bin -bn {cls.srcn} -m {cls.modname}")
+        bright = True
+        for z in re.findall(r"-Z.?", args):
+            if z[-1] in "Z ":
+                bright = not bright
+            elif z[-1] in "+yYtT1":
+                bright = True
+            else:
+                bright = False
+        if bright:
+            cls.features = 1
+        else:
+            cls.features = 3
         super().set_args(args, nproc)
