@@ -62,7 +62,8 @@ class SamplerSuns(BaseSampler):
             ptkwargs = {}
         areakwargs.update(samplerlevel=self._slevel + 1)
         self._areakwargs = dict(metricset=('avglum', 'loggcr', 'xpeak',
-                                           'ypeak'), metricfunc=np.max)
+                                           'ypeak'), featurefunc=np.max,
+                                edgemode=-self.t0)
         self._areakwargs.update(areakwargs)
         self._ptkwargs = ptkwargs
         self.nlev = nlev
@@ -135,7 +136,7 @@ class SamplerSuns(BaseSampler):
             the mapping for drawing suns
         areamapper: raytraverse.mapper.PlanMapper
             the mapping for drawing points
-        specguide: raytraverse.lightfield.LightPlaneKD
+        specguide: Union[raytraverse.lightfield.LightPlaneKD, Bool]
             sky source lightfield to use as specular guide for sampling
         recover: continue run on top of existing files, if false, overwrites
             previous run.
@@ -163,13 +164,14 @@ class SamplerSuns(BaseSampler):
         self._areaweights = None
         levels = self.sampling_scheme(skymapper)
         super().run(skymapper, areamapper.name, levels, **kwargs)
-        return SunsPlaneKD(self.scene, self.vecs, self._areamapper,
+        return SunsPlaneKD(self.scene, self.idxvecs(), self._areamapper,
                            f"{self._skymapper.name}_sun")
 
     def _init4run(self, levels, **kwargs):
         """(re)initialize object for new run, ensuring properties are cleared
         prior to executing sampling loop"""
         leveliter = super()._init4run(levels)
+        self.slices = []
         if self._recovery_data is None:
             return leveliter
         levels2run = []
@@ -241,7 +243,7 @@ class SamplerSuns(BaseSampler):
                 emode = 'constant'
             det = draw.get_detail(nweights,
                                   *filterdict[self.detailfunc], mode=emode)
-            mfunc = self._areakwargs['metricfunc']
+            mfunc = self._areakwargs['featurefunc']
             det = np.transpose(det.reshape(self._areaweights.shape),
                                (3, 4, 0, 1, 2))
             det = mfunc(det, axis=2)
@@ -294,7 +296,7 @@ class SamplerSuns(BaseSampler):
 
     def _sample_sun(self, suni, sunpos, adraws):
         """this function is for calling with a process pool, by declaring the
-        sun sampler point after the child process is forked/spawned the
+        sun sampler point after the child process is forked the
         call to engine.load_source happens on an isolated memory instance,
         allowing for concurrency on different scenes, despite the singleton/
         global namespace issues of the cRtrace instance."""
@@ -361,6 +363,18 @@ class SamplerSuns(BaseSampler):
         self._dump_vecs(vecs)
         idx = self.slices[-1].indices(self.slices[-1].stop)
         level_desc = f"Level {len(self.slices)} of {len(self.levels)}"
+
+        lums = self._run_sample(idx, vecs, level_desc)
+        # initialize areaweights here now that we know the shape
+        if len(self.lum) == 0:
+            self.lum = lums
+            self._areaweights = np.zeros((*self.lum.shape[1:],
+                                          *self._wshape(0)))
+        else:
+            self.lum = np.concatenate((self.lum, lums), 0)
+        return lums
+
+    def _run_sample(self, idx, vecs, level_desc):
         # if engine is configured for internal multiprocessing run on one
         # process, else use environment cap. Generally, if -ab > 0 then run
         # with rtrace -n X for better memory efficiency, else, use processpool
@@ -370,17 +384,10 @@ class SamplerSuns(BaseSampler):
         else:
             cap = None
         lums = pool_call(self._sample_sun, list(zip(range(*idx), vecs,
-                         self._areadraws)), desc=level_desc, cap=cap,
+                                                    self._areadraws)),
+                         desc=level_desc, cap=cap,
                          pbar=self.scene.dolog)
-        lums = np.array(lums)
-        # initialize areaweights here now that we know the shape
-        if len(self.lum) == 0:
-            self.lum = lums
-            self._areaweights = np.zeros((*self.lum.shape[1:],
-                                          *self._wshape(0)))
-        else:
-            self.lum = np.concatenate((self.lum, lums), 0)
-        return lums
+        return np.array(lums)
 
     def _update_weights(self, si, lum):
         """only need to update areaweights, base weights are only masked"""
@@ -428,13 +435,15 @@ class SamplerSuns(BaseSampler):
         self.slices.append(slice(v0, v0 + len(vecs)))
         vfile = (f"{self.scene.outdir}/{self._areamapper.name}/"
                  f"{self._skymapper.name}_{self.stype}.tsv")
+        # file format: level idx sx sy sz
+        np.savetxt(vfile, self.idxvecs(), ("%d", "%d", "%.4f", "%.4f", "%.4f"))
+
+    def idxvecs(self):
         idx = np.arange(len(self.vecs))[:, None]
         level = np.zeros_like(idx, dtype=int)
         for sl in self.slices[1:]:
             level[sl.start:] += 1
-        idxvecs = np.hstack((level, idx, self.vecs))
-        # file format: level idx sx sy sz
-        np.savetxt(vfile, idxvecs, ("%d", "%d", "%.4f", "%.4f", "%.4f"))
+        return np.hstack((level, idx, self.vecs))
 
     @staticmethod
     def _plot_dist(ps, vm, outf, fisheye=True):
