@@ -47,7 +47,7 @@ class SrcSamplerPt(SamplerPt):
             # otherwise luminance detail gets undersanmpled
             self.ub = 1
             engine.update_ospec(engine.ospec + "LNM")
-            kwargs.update(features=engine.features)
+        kwargs.update(features=engine.features)
         super().__init__(scene, engine, stype=stype, **kwargs)
         # update parameters post init
         #: path to source scene file
@@ -107,14 +107,15 @@ class SrcSamplerPt(SamplerPt):
                     uv = self._mapper.idx2uv(np.arange(int(np.prod(dres))),
                                              dres, False)
                     insrc = vm.in_view(self._mapper.uv2xyz(uv), False)
-                    insrc = np.tile(insrc, self.weights.shape[0])
+                    if self.features > 1:
+                        insrc = np.tile(insrc, self.weights.shape[0])
                     # definite draw on source region
                     p[0:len(insrc)][insrc] = self.t1 * 2 * self.ub
             if self.features > 1:
                 p = self.featurefunc(p.reshape(self.weights.shape),
                                      axis=0).ravel()
             pdraws = draw.from_pdf(p, self._threshold(level),
-                                   lb=self.lb, ub=self.ub)
+                                   lb=self.lb, ub=self.ub, minsamp=1)
         return pdraws, p
 
     def _process_features(self, lum):
@@ -138,6 +139,10 @@ class SrcSamplerPt(SamplerPt):
             pipeline([f"oconv -w {self.sourcefile}"], outfile=f)
         afac = 0.0
         srcoct = f"./{self.scene.outdir}/" + srcoct.rsplit("/")[-1]
+        if self.features > 1:
+            vlambda = (1/3, 1/3, 1/3)
+        else:
+            vlambda = (0.265, 0.670, 0.065)
         if self.lights.size > 0:
             # make rays point at center of sources from 6 cardinal directions
             box = np.vstack((np.eye(3), -np.eye(3))) * .001
@@ -150,7 +155,7 @@ class SrcSamplerPt(SamplerPt):
             lums = np.array([float(i) for i in
                              icheck(brays).split()]).reshape(-1, 3)
             # get the max luminance for each source
-            llum = np.max(io.rgb2rad(lums).reshape(len(self.lights), -1), 1)
+            llum = np.max(io.rgb2rad(lums, vlambda).reshape(len(self.lights), -1), 1)
             # find the distance along upaxis
             dray = np.abs(self.lights[:, 0:3] - point[None])[:, upaxis]
             radius = np.sqrt(self.lights[:, 4] / np.pi)
@@ -163,7 +168,7 @@ class SrcSamplerPt(SamplerPt):
                                 "-dc 1 -ds 0 -dt 0 -dj 0", srcoct, 1)
             # hopefully this is above any light source geometry
             ray = np.array([0, 0, 1e7, 0, 0, 1]).reshape(-1, 6)
-            illum = io.rgb2rad([float(i) for i in icheck(ray).split()])
+            illum = io.rgb2rad([float(i) for i in icheck(ray).split()], vlambda)
             afac += illum / np.pi
         if afac > 0:
             self.accuracy = self.accuracy * afac
@@ -197,6 +202,8 @@ class SrcSamplerPt(SamplerPt):
         ires = self.idres*180/self._mapper.viewangle
         # 1/2 for nyquist
         level_res = ires*np.power(2, np.arange(self.nlev))/2
+        # last level with refinement
+        rlevel = len(self._samplelevels) - 2
         if self.sources.size > 0:
             minres = 180/self.sources[:, 3]
             level_idx = np.searchsorted(level_res, minres)
@@ -206,9 +213,9 @@ class SrcSamplerPt(SamplerPt):
                     rsrc = self._reflect(src[None])
                 else:
                     rsrc = []
-                # ensure atleast 2 levels of source "clean-up" else use
+                # ensure atleast 1 levels of source "clean-up" else use
                 # a srcviewsampler
-                if idx >= len(self._samplelevels) - 2:
+                if idx >= rlevel:
                     self._viewdirections.append(src[0:4])
                     self._viewdirections += rsrc
                     self._isdistant += [True]*(len(rsrc) + 1)
@@ -234,13 +241,7 @@ class SrcSamplerPt(SamplerPt):
             # allocate direct source sampling to level below nyquist limit
             for idx, light, size in zip(level_idx, lightdir, appsize):
                 li = np.concatenate((light, [size]))
-                # only srcviewsample lights if beyond limit of sampling
-                # (no clean-up)
-                if idx >= len(self._samplelevels):
-                    self._viewdirections.append(li)
-                    self._isdistant.append(False)
-                else:
-                    self._samplelevels[idx].append(li)
+                self._samplelevels[min(idx, rlevel)].append(li)
         self._viewdirections = np.array(self._viewdirections)
 
     def _run_callback(self, point, posidx, vm, write=True, **kwargs):
