@@ -14,13 +14,16 @@ import re
 
 import numpy as np
 from scipy.interpolate import interp1d
-from skyfield.api import Topos, utc, Loader
+from skyfield.api import Topos, utc, load
 
 from raytraverse import translate
 from raytraverse.formatter import RadianceFormatter
 
-load = Loader(os.path.dirname(translate.__file__))
-planets = load('de421.bsp')
+# bsp file made with:
+# python -m jplephem excerpt 2020/1/1 2030/1/1 \
+# https://naif.jpl.nasa.gov/pub/naif/generic_kernels/spk/planets/de432s.bsp \
+# de432_2020s.bsp
+planets = load(os.path.dirname(translate.__file__) + '/de432_2020s.bsp')
 sun = planets['sun']
 earth = planets['earth']
 
