@@ -11,7 +11,8 @@
 
 import numpy as np
 from scipy.ndimage import gaussian_filter, uniform_filter
-from scipy.spatial import cKDTree
+from scipy.spatial import cKDTree, Voronoi
+from shapely.geometry import Polygon
 
 
 def norm(v):
@@ -503,7 +504,7 @@ def cull_vectors(vecs, tol):
     else:
         pkd = vecs
         vecs = pkd.data
-    pairs = pkd.query_ball_tree(pkd, tol)
+    pairs = pkd.query_ball_tree(pkd, tol, 2)
     flt = np.full(len(vecs), True)
     # keep track of culled indices to avoid removing chains of points
     flagged = set()
@@ -517,8 +518,74 @@ def cull_vectors(vecs, tol):
 
 
 def reflect(ray, normal, returnmasked=False):
-    refl = ray - 2 * normal * np.einsum("ij,kj->ik", ray, normal)
+    refl = (ray[:, None] -
+            2 * normal[None] * np.einsum("ij,kj->ik", ray, normal)[..., None])
+    try:
+        refl = np.squeeze(refl, 0)
+    except ValueError:
+        pass
     n = np.isclose(np.linalg.norm(refl, axis=-1), 1)
     if returnmasked:
         return refl[n]
     return refl, n
+
+
+def simple_take(ar, *slices, axes=None):
+    """consistent array indexing with arrays, lists, tuples and slices
+
+    Parameters
+    ----------
+    ar: np.array
+        the multidimensional arary to index
+    slices: tuple
+        if sequence, takes those indices along axis, if None, take whole
+        dimension, if slice, applies to index array before take
+    axes: Union[Sequence, int], optional
+        when None, slices are automatically taken starting on axes 0. Use this
+        argument to only operate on a subset of dimensions.
+
+    Returns
+    -------
+    np.array
+        matches ndims of ar
+    """
+    if axes is None:
+        axes = np.arange(len(slices))
+    else:
+        axes = np.ravel(axes)
+    for i, j in zip(slices, axes):
+        if i is None:
+            pass
+        elif type(i) == slice:
+            k = np.arange(ar.shape[j])[i]
+            ar = np.take(ar, k, j)
+        else:
+            ar = np.take(ar, np.ravel(i), j)
+    return ar
+
+
+def calc_omega(vecs, pm):
+    """calculate area"""
+    # border capture any infinite edges
+    bordered = np.concatenate((vecs,
+                               pm.bbox_vertices(pm.area**.5 * 10)))
+    # due to precision errors, Qhull may return fewer regions than
+    # vertices, the QJ options helps this...
+    vor = Voronoi(bordered[:, 0:2], qhull_options="Qbb Qc QJ")
+    # but in case of failure, this will distribute the area of the duplicate
+    # region evenly among the enclosed vertices by scaling by 1/# of vertices
+    # using each region.
+    if len(vor.regions) < len(vor.point_region):
+        r, idx, inv, cnt = np.unique(vor.point_region[:len(vecs)],
+                                     return_index=True, return_inverse=True,
+                                     return_counts=True)
+        scale = 1./cnt[inv]
+    else:
+        scale = 1.
+    omega = np.zeros(len(vecs))
+    for i in range(len(vecs)):
+        region = vor.regions[vor.point_region[i]]
+        p = Polygon(vor.vertices[region])
+        omega[i] = p.intersection(pm.boundary).area
+    omega *= scale
+    return np.asarray(omega)
